<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.2.0
 *
 * @package    Mailup
 * @subpackage Mailup/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Mailup
 * @subpackage Mailup/public
 * @author     Your Name <email@example.com>
 */
class Mailup_Public
{

    /**
     * The ID of this plugin.
     *
     * @since    1.2.0
     * @access   private
     * @var      string    $mailup    The ID of this plugin.
     */
    private $mailup;

    /**
     * The version of this plugin.
     *
     * @since    1.2.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;
    
    private $tag_name = 'mailup_form';

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.2.0
     * @param      string    $mailup       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($mailup, $version)
    {
        $this->mailup = $mailup;
        $this->version = $version;
        $this->load_dependencies();
    }

    private function load_dependencies()
    {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-mailup-model.php';
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.2.0
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Mailup_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Mailup_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style($this->mailup, plugin_dir_url(__FILE__) . 'css/mailup-public.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.2.0
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Mailup_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Mailup_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        if (!is_admin()) {
            $lang = Mailup_i18n::getLanguage();
            wp_enqueue_script($this->mailup . '_validate', plugin_dir_url(dirname(__FILE__)) . 'admin/js/jquery.validate.min.js', array( 'jquery' ), '1.19.3', false);
            if ($lang) {
                wp_enqueue_script(sprintf('%s_validate_loc_%s', $this->mailup, $lang), sprintf('%sadmin/js/localization/messages_%s.js', plugin_dir_url(dirname(__FILE__)), $lang), array($this->mailup . '_validate'), '1.19.3', false);
            }
            wp_enqueue_script($this->mailup, plugin_dir_url(__FILE__) . 'js/mailup-public.js', array( 'jquery', $this->mailup . '_validate' ), $this->version, false);
            
            wp_localize_script($this->mailup, 'mailup_params', array(
                'ajax_url' => admin_url('admin-ajax.php'),
                'ajaxNonce' => wp_create_nonce('ajax-nonce')
            ));
        }
    }

    public function register_shortcodes()
    {
        if (!is_admin()) {
            add_shortcode($this->tag_name, array( $this, 'create_form'));
        }
    }

    public function register_inline($style)
    {
        wp_register_style('mupwp-inline-style', false, array( $this->mailup ));
        wp_enqueue_style('mupwp-inline-style');
        wp_add_inline_style('mupwp-inline-style', $style);
    }


    public function create_form()
    {
        ob_start();
        $this->model = new Mailup_Model($this->mailup);
        $form = $this->model->get_fe_form();
        $this->register_inline($form->custom_css);
        if ($this->model->has_tokens() && $form) {
            include(dirname(__FILE__).'/partials/mailup-public-display.php');
        }
        return ob_get_clean();
    }

    public function mupwp_save_contact()
    {
        if (is_array($_POST['parameters'])) {
            $this->model = new Mailup_Model($this->mailup);
            $parameters = array_filter($_POST['parameters']);
            $this->model->add_recipient($parameters);
        }
        die();
    }
}